@@ -17,6 +17,7 @@ from __future__ import absolute_import
 import os
 import sys
 import traceback
+from distutils.spawn import find_executable
 import xenv
 
 import LbPlatformUtils.describe
@@ -589,11 +590,12 @@ class LbRun(xenv.Script):
         self.log.debug("handling required externals")
         # get list of ext dirs from LCG_externals_<platform>.txt
         # the result is a dictionary {name: (path, deps)}
-        exts_info = dict(
-            (x[0].lower(), (os.path.join(lcg_path, x[3]), parse_deps_list(x[4])))
-            for x in [[s.strip() for s in x.split(";")] for x in [open(ext_info_file)]]
-            if len(x) == 5
-        )
+        with open(ext_info_file) as fp:
+            exts_info = dict(
+                (x[0].lower(), (os.path.join(lcg_path, x[3]), parse_deps_list(x[4])))
+                for x in [[s.strip() for s in x.split(";")] for x in fp]
+                if len(x) == 5
+            )
 
         # we want case insensitive lookup and the use may specify
         #  --ext A --ext B,C
@@ -780,30 +782,11 @@ class LbRun(xenv.Script):
         #        'from . import path'
         from LbEnv.ProjectEnv import path, SearchPathEntry
 
-        try:
-            if self.project.lower() == "lhcbdirac":
-                self.log.debug("try new LHCbDirac environment tool")
-                from LbEnv.ProjectEnv.LHCbDirac import (
-                    getLHCbDiracEnv,
-                    LHCbDiracEnvError,
-                )
-
-                # different convention between lb-run and lhcbdirac
-                for item in getLHCbDiracEnv(
-                    "pro" if self.version == "prod" else self.version
-                ).items():
-                    self.opts.actions.append(("set", item))
-                # FIXME: this section is a copy of the code at the end of the
-                #        function, but it's not factored out because this is
-                #        anyway a temporary workaround
-                try:
-                    super(LbRun, self)._makeEnv()
-                    return
-                except SystemExit as exc:
-                    raise SystemExit(exc.code | 64)
-        except LHCbDiracEnvError:
-            # Could not use new LHCbDirac environment tool, use old style
-            self.log.debug("fall back to legacy LHCbDirac environment")
+        if self.project.lower() == "lhcbdirac":
+            self.log.error(
+                "lb-run LHCbDIRAC is no longer available, please use lb-dirac instead"
+            )
+            raise SystemExit(64)
 
         if self.opts.use_grid:
             self.log.warning("the option --use-grid is ignored (deprecated)")
@@ -1036,7 +1019,10 @@ class LbRun(xenv.Script):
         if self.opts.container == "singularity":
             self.log.debug("preparing singularity wrapper command")
             # wrap command in container
-            wrapper = ["singularity", "exec", "--bind", "/cvmfs", "--userns"]
+            # PATH might be changed when launching the environment so use an absolute filename
+            singularity_exe = find_executable("singularity")
+            self.log.debug("Using singularity at: %s", singularity_exe)
+            wrapper = [singularity_exe, "exec", "--bind", "/cvmfs", "--userns"]
             if "X509_USER_PROXY" in os.environ:
                 wrapper += ["--bind", os.environ["X509_USER_PROXY"]]
 
